Index: modules/video_output/opengl.c
===================================================================
--- modules/video_output/opengl.c	(revision 16429)
+++ modules/video_output/opengl.c	(working copy)
@@ -162,6 +162,16 @@
 #define SPEED_TEXT N_( "OpenGL cube rotation speed" )
 #define SPEED_LONGTEXT N_( "Rotation speed of the OpenGL cube effect, if " \
         "enabled." )
+
+#define LEFT_TEXT N_( "OpenGL Left Offset" )
+#define LEFT_LONGTEXT N_( "Left Offset of the OpenGL rendering" )
+#define RIGHT_TEXT N_( "OpenGL Right Offset" )
+#define RIGHT_LONGTEXT N_( "Right Offset of the OpenGL rendering" )
+#define TOP_TEXT N_( "OpenGL Top Offset" )
+#define TOP_LONGTEXT N_( "Top Offset of the OpenGL rendering" )
+#define BOTTOM_TEXT N_( "OpenGL Bottom Offset" )
+#define BOTTOM_LONGTEXT N_( "Bottom Offset of the OpenGL rendering" )
+		
 #define EFFECT_TEXT N_("Effect")
 #define EFFECT_LONGTEXT N_( \
     "Several visual OpenGL effects are available." )
@@ -186,6 +196,16 @@
     add_shortcut( "opengl" );
     add_float( "opengl-cube-speed", 2.0, NULL, SPEED_TEXT,
                     SPEED_LONGTEXT, VLC_TRUE );
+	
+    add_float( "opengl-left-offset", -1.0, NULL, LEFT_TEXT, 
+                    LEFT_LONGTEXT, VLC_TRUE ); 
+    add_float( "opengl-right-offset", 1.0, NULL, RIGHT_TEXT, 
+                    RIGHT_LONGTEXT, VLC_TRUE ); 
+    add_float( "opengl-top-offset", 1.0, NULL, TOP_TEXT, 
+                    TOP_LONGTEXT, VLC_TRUE ); 
+    add_float( "opengl-bottom-offset", -1.0, NULL, BOTTOM_TEXT, 
+                    BOTTOM_LONGTEXT, VLC_TRUE ); 
+
 #ifdef OPENGL_MORE_EFFECT
     add_integer_with_range( "opengl-accuracy", 4, 1, 10, NULL, ACCURACY_TEXT,
                     ACCURACY_LONGTEXT, VLC_TRUE );
@@ -225,6 +245,11 @@
 
     float       f_speed;
     float       f_radius;
+	
+   float        f_left_offset;
+   float        f_right_offset;
+   float        f_top_offset;
+   float        f_bottom_offset;
 };
 
 /*****************************************************************************
@@ -291,6 +316,11 @@
 
     p_sys->f_speed = var_CreateGetFloat( p_vout, "opengl-cube-speed" );
     p_sys->f_radius = var_CreateGetFloat( p_vout, "opengl-cylinder-radius" );
+	
+    p_sys->f_left_offset = var_CreateGetFloat( p_vout, "opengl-left-offset" );
+    p_sys->f_right_offset = var_CreateGetFloat( p_vout, "opengl-right-offset" );
+    p_sys->f_top_offset = var_CreateGetFloat( p_vout, "opengl-top-offset" );
+    p_sys->f_bottom_offset = var_CreateGetFloat( p_vout, "opengl-bottom-offset" );
 
     p_vout->pf_init = Init;
     p_vout->pf_end = End;
@@ -889,10 +919,10 @@
     {
         glEnable( VLCGL_TARGET );
         glBegin( GL_POLYGON );
-        glTexCoord2f( f_x, f_y ); glVertex2f( -1.0, 1.0 );
-        glTexCoord2f( f_width, f_y ); glVertex2f( 1.0, 1.0 );
-        glTexCoord2f( f_width, f_height ); glVertex2f( 1.0, -1.0 );
-        glTexCoord2f( f_x, f_height ); glVertex2f( -1.0, -1.0 );
+        glTexCoord2f( f_x, f_y ); glVertex2f( p_sys->f_left_offset, p_sys->f_top_offset );
+        glTexCoord2f( f_width, f_y ); glVertex2f( p_sys->f_right_offset, p_sys->f_top_offset );
+        glTexCoord2f( f_width, f_height ); glVertex2f( p_sys->f_right_offset, p_sys->f_bottom_offset );
+        glTexCoord2f( f_x, f_height ); glVertex2f( p_sys->f_left_offset, p_sys->f_bottom_offset );
         glEnd();
     }
     else
